# coding=utf-8

"""
Response class
"""


class Response(object):
    """
    API response class
    """

    def __init__(self, code, body):
        self.__status_code = code
        self.__response_body = body

    def get_status_code(self):
        """
        :return: integer
        """
        return self.__status_code

    def get_response(self):
        """
        :return: string
        """
        return self.__response_body

    def is_successful(self):
        """
        :return: boolean
        """
        return int(self.__status_code) < 400

    def get_error_msg(self):
        """
        :return: string
        """
        return self.__response_body['errorMsg']

    def get_errors(self):
        """
        :return: collection
        """
        errors = {
        } if not self.__response_body['errors'] else self.__response_body['errors']

        return errors



# coding=utf-8


"""
retailCRM API client v4 tests
"""

import unittest
import os
import retailcrm


class TestVersion4(unittest.TestCase):
    """
    TestClass for v4
    """

    def setUp(self):
        """
        Setup
        """
        self.client = retailcrm.v4(
            os.getenv('RETAILCRM_URL'), os.getenv('RETAILCRM_KEY'))

    def test_wrong_api_url(self):
        """
        V4 Test wrong api url
        """
        client = retailcrm.v4(
            'https://epoqwieqwpoieqpwoeiqpwoeiq.retailcrm.ru', '98sdf9sj8fsd9fjs9dfjs98')
        response = client.statistic_update()

        self.assertTrue(response.is_successful(), False)
        self.assertEqual(response.get_error_msg(), 'Account does not exist.')

    def test_wrong_api_key(self):
        """
        V4 Test wrong api key
        """
        client = retailcrm.v3(os.getenv('RETAILCRM_URL'),
                              '98sdf9sj8fsd9fjs9dfjs98')
        response = client.statistic_update()

        self.assertEqual(response.get_error_msg(), 'Wrong "apiKey" value.')

    def test_missing_api_key(self):
        """
        V4 Test missing api key
        """
        client = retailcrm.v4(os.getenv('RETAILCRM_URL'), None)
        response = client.statistic_update()

        self.assertEqual(response.get_error_msg(), '"apiKey" is missing.')

    def test_api_versions(self):
        """
        V4 Test api-versions method
        """
        response = self.client.api_versions()

        self.assertTrue(response.is_successful(), True)

    def test_api_credentials(self):
        """
        V4 Test api-credentials method
        """
        response = self.client.api_credentials()

        self.assertTrue(response.is_successful(), True)



# coding=utf-8

"""
Setup file
"""

import os
from setuptools import setup


def read(fname):
    """Read readme for long description"""
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='retailcrm',
    version='5.0.0',
    description='retailCRM API client',
    long_description=read('README.md'),
    url='https://github.com/retailcrm/api-client-python',
    author='retailCRM',
    author_email='integration@retailcrm.ru',
    keywords='crm, saas, rest, e-commerce',
    license='MIT',
    packages=['retailcrm', 'tests'],
    package_data={},
    install_requires=['requests', 'multidimensional_urlencode', 'nose'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Other Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
